pub struct ClientCredentialsOAuthFlow {
pub token_url: String,
pub refresh_url: Option<String>,
pub scopes: HashMap<String, String>,
}Expand description
The client credentials OAuth2 flow.
Fields
token_url: Stringrefresh_url: Option<String>scopes: HashMap<String, String>Trait Implementations
Sourceimpl Clone for ClientCredentialsOAuthFlow
impl Clone for ClientCredentialsOAuthFlow
Sourcefn clone(&self) -> ClientCredentialsOAuthFlow
fn clone(&self) -> ClientCredentialsOAuthFlow
Returns a duplicate of the value. Read more
1.0.0 · Sourcefn clone_from(&mut self, source: &Self)
fn clone_from(&mut self, source: &Self)
Performs copy-assignment from
source. Read moreSourceimpl Debug for ClientCredentialsOAuthFlow
impl Debug for ClientCredentialsOAuthFlow
Sourceimpl<'de> Deserialize<'de> for ClientCredentialsOAuthFlow
impl<'de> Deserialize<'de> for ClientCredentialsOAuthFlow
Sourcefn deserialize<__D>(__deserializer: __D) -> Result<Self, __D::Error>where
__D: Deserializer<'de>,
fn deserialize<__D>(__deserializer: __D) -> Result<Self, __D::Error>where
__D: Deserializer<'de>,
Deserialize this value from the given Serde deserializer. Read more
Sourceimpl JsonSchema for ClientCredentialsOAuthFlow
impl JsonSchema for ClientCredentialsOAuthFlow
Sourcefn schema_id() -> Cow<'static, str>
fn schema_id() -> Cow<'static, str>
Returns a string that uniquely identifies the schema produced by this type. Read more
Sourcefn json_schema(generator: &mut SchemaGenerator) -> Schema
fn json_schema(generator: &mut SchemaGenerator) -> Schema
Generates a JSON Schema for this type. Read more
Sourcefn inline_schema() -> bool
fn inline_schema() -> bool
Whether JSON Schemas generated for this type should be included directly in parent schemas,
rather than being re-used where possible using the
$ref keyword. Read moreAuto Trait Implementations
impl Freeze for ClientCredentialsOAuthFlow
impl RefUnwindSafe for ClientCredentialsOAuthFlow
impl Send for ClientCredentialsOAuthFlow
impl Sync for ClientCredentialsOAuthFlow
impl Unpin for ClientCredentialsOAuthFlow
impl UnsafeUnpin for ClientCredentialsOAuthFlow
impl UnwindSafe for ClientCredentialsOAuthFlow